#[non_exhaustive]pub enum Relation {
Reply(Reply),
Replacement(Replacement),
Reference(Reference),
Annotation(Annotation),
Thread(Thread),
}Expand description
Relationship information about an encrypted event.
Outside of the encrypted payload to support server aggregation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Reply(Reply)
A reply to another event.
Replacement(Replacement)
An event that replaces another event.
Reference(Reference)
A reference to another event.
Annotation(Annotation)
An annotation to an event.
Thread(Thread)
An event that belongs to a thread.
Implementations
Sourceimpl Relation
impl Relation
Sourcepub fn rel_type(&self) -> Option<RelationType>
pub fn rel_type(&self) -> Option<RelationType>
The type of this Relation.
Returns an Option because the Reply relation does not have a rel_type field.
Sourcepub fn data(&self) -> Cow<'_, JsonObject>
pub fn data(&self) -> Cow<'_, JsonObject>
The associated data.
The returned JSON object holds the contents of m.relates_to, including rel_type and
event_id if present, but not things like m.new_content for m.replace relations that
live next to m.relates_to.
Prefer to use the public variants of Relation where possible; this method is meant to
be used for custom relations only.